@@ -54,6 +54,7 @@ from .const import (
     G90Commands, REMOTE_PORT,
     REMOTE_TARGETED_DISCOVERY_PORT,
     LOCAL_TARGETED_DISCOVERY_PORT,
+    NOTIFICATIONS_PORT,
     G90ArmDisarmTypes,
 )
 from .base_cmd import G90BaseCommand
@@ -87,26 +88,22 @@ class G90Alarm:  # pylint: disable=too-many-public-methods
      protocol commands on WiFi interface, currently the devices don't allow it
      to be customized
     :type port: int, optional
-    :param sock: The existing socket to operate on, instead of
-     creating one internally. Primarily used by the tests to mock the network
-     traffic
-    :type sock: socket.socket or None, optional
     :param reset_occupancy_interval: The interval upon that the sensors are
      simulated to go into inactive state.
     :type reset_occupancy_interval: int, optional
     """
     # pylint: disable=too-many-instance-attributes
-    def __init__(self, host, port=REMOTE_PORT, sock=None,
+    def __init__(self, host, port=REMOTE_PORT,
                  reset_occupancy_interval=3):
         self._host = host
         self._port = port
         self._sensors = []
         self._devices = []
         self._notifications = None
-        self._sock = sock
         self._sensor_cb = None
         self._armdisarm_cb = None
         self._door_open_close_cb = None
+        self._alarm_cb = None
         self._reset_occupancy_interval = reset_occupancy_interval
         self._alert_config = None
         self._sms_alert_when_armed = False
@@ -123,7 +120,7 @@ class G90Alarm:  # pylint: disable=too-many-public-methods
          command invocation
         """
         cmd = await G90BaseCommand(
-            self._host, self._port, code, data, sock=self._sock).process()
+            self._host, self._port, code, data).process()
         return cmd.result
 
     def paginated_result(self, code, start=1, end=None):
@@ -140,7 +137,7 @@ class G90Alarm:  # pylint: disable=too-many-public-methods
           yields :class:`.G90PaginatedResponse` instance
         """
         return G90PaginatedResult(
-            self._host, self._port, code, start, end, sock=self._sock
+            self._host, self._port, code, start, end
         ).process()
 
     @classmethod
@@ -208,6 +205,32 @@ class G90Alarm:  # pylint: disable=too-many-public-methods
 
         return self._sensors
 
+    async def find_sensor(self, idx, name):
+        """
+        Finds sensor by index and name.
+
+        :param int idx: Sensor index
+        :param str name: Sensor name
+        :return: Sensor instance
+        :rtype :class:`.G90Sensor`|None
+        """
+        sensors = await self.get_sensors()
+
+        # Fast lookup by direct index
+        if idx < len(sensors) and sensors[idx].name == name:
+            sensor = sensors[idx]
+            _LOGGER.debug('Found sensor via fast lookup: %s', sensor)
+            return sensor
+
+        # Fast lookup failed, perform slow one over the whole sensors list
+        for sensor in sensors:
+            if sensor.index == idx and sensor.name == name:
+                _LOGGER.debug('Found sensor: %s', sensor)
+                return sensor
+
+        _LOGGER.error('Sensor not found: idx=%s, name=%s', idx, name)
+        return None
+
     @property
     async def devices(self):
         """
@@ -397,22 +420,11 @@ class G90Alarm:  # pylint: disable=too-many-public-methods
          alerts (only for `door` type sensors, if door open/close alerts are
          enabled)
         """
-        sensors = await self.sensors
-
-        # Fast lookup by direct index
-        if idx < len(sensors) and sensors[idx].name == name:
-            sensor = [sensors[idx]]
-        # Fast lookup failed, perform slow one over the whole sensors list
-        else:
-            sensor = [
-                x for x in sensors
-                if x.index == idx and x.name == name
-            ]
+        sensor = await self.find_sensor(idx, name)
         if sensor:
-            _LOGGER.debug('Found sensor: %s', sensor[0])
             _LOGGER.debug('Setting occupancy to %s (previously %s)',
-                          occupancy, sensor[0].occupancy)
-            sensor[0].occupancy = occupancy
+                          occupancy, sensor.occupancy)
+            sensor.occupancy = occupancy
 
             # Emulate turning off the occupancy - most of sensors will not
             # notify the device of that, nor the device would emit such
@@ -427,7 +439,7 @@ class G90Alarm:  # pylint: disable=too-many-public-methods
             alert_config_flags = await self.alert_config
             door_close_alert_enabled = (
                 G90AlertConfigFlags.DOOR_CLOSE in alert_config_flags)
-            sensor_is_door = sensor[0].type == G90SensorTypes.DOOR
+            sensor_is_door = sensor.type == G90SensorTypes.DOOR
 
             # Alarm panel could emit door close alerts (if enabled) for sensors
             # of type `door`, and such event will be used to reset the
@@ -439,16 +451,14 @@ class G90Alarm:  # pylint: disable=too-many-public-methods
                               ' (alert config flags %s),'
                               ' closing event will be emulated upon'
                               ' %s seconds',
-                              name, sensor[0].type, alert_config_flags,
+                              name, sensor.type, alert_config_flags,
                               self._reset_occupancy_interval)
                 G90Callback.invoke_delayed(
                     self._reset_occupancy_interval,
-                    reset_sensor_occupancy, sensor[0])
+                    reset_sensor_occupancy, sensor)
 
             # Invoke per-sensor callback if provided
-            G90Callback.invoke(sensor[0].state_callback, occupancy)
-        else:
-            _LOGGER.error('Sensor not found: idx=%s, name=%s', idx, name)
+            G90Callback.invoke(sensor.state_callback, occupancy)
 
         # Invoke global callback if provided
         G90Callback.invoke(self._sensor_cb, idx, name, occupancy)
@@ -535,18 +545,55 @@ class G90Alarm:  # pylint: disable=too-many-public-methods
     def armdisarm_callback(self, value):
         self._armdisarm_cb = value
 
-    async def listen_device_notifications(self, sock=None):
+    async def _internal_alarm_cb(self, sensor_idx, sensor_name):
+        """
+        Callback that invoked when alarm is triggered. Fires alarm callback if
+        set by the user with `:property:G90Alarm.alarm_callback`.
+        Please note the callback is for internal use by the class.
+
+        :param int: Index of the sensor triggered alarm
+        :param str: Sensor name
+        """
+        sensor = await self.find_sensor(sensor_idx, sensor_name)
+        # The callback is still delivered to the caller even if the sensor
+        # isn't found, only `extra_data` is skipped. That is to ensur the
+        # important callback isn't filtered
+        extra_data = sensor.extra_data if sensor else None
+
+        G90Callback.invoke(
+            self._alarm_cb, sensor_idx, sensor_name, extra_data
+        )
+
+    @property
+    def alarm_callback(self):
+        """
+        Get or set device alarm callback, the callback is invoked when
+        device alarm triggers.
+
+        :type:
+          .. py:function:: ()(
+            sensor_idx: int, sensor_name: str, extra_data: str|None
+          )
+        """
+        return self._alarm_cb
+
+    @alarm_callback.setter
+    def alarm_callback(self, value):
+        self._alarm_cb = value
+
+    async def listen_device_notifications(
+        self, host='0.0.0.0', port=NOTIFICATIONS_PORT
+    ):
         """
         Starts internal listener for device notifications/alerts.
 
-        :param sock: socket instance to listen on, mostly used by tests
-        :type: socket.socket
         """
         self._notifications = G90DeviceNotifications(
+            host=host, port=port,
             sensor_cb=self._internal_sensor_cb,
             door_open_close_cb=self._internal_door_open_close_cb,
             armdisarm_cb=self._internal_armdisarm_cb,
-            sock=sock)
+            alarm_cb=self._internal_alarm_cb)
         await self._notifications.listen()
 
     def close_device_notifications(self):
